@@ -1,6 +1,7 @@
  /* ============================================================
- * 
+ *
  * Copyright (C) 2006 Tom Albers <tomalbers@kde.nl>
+ * Copyright (C) 2006 Bram Schoenmakers <bramschoenmakers@kde.nl
  *
  * Orginal copied from digikam: Leonid Zeitlin <lz@europe.com>
  *
@@ -9,12 +10,12 @@
  * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * ============================================================ */
 
 // Local includes.
@@ -34,10 +35,20 @@ void DCOPIface::suspend()
 {
     emit signalSuspend( true );
 }
- 
+
 void DCOPIface::resume()
 {
     emit signalSuspend( false );
 }
 
+void DCOPIface::doTinyBreak()
+{
+    emit signalDoTinyBreak();
+}
+
+void DCOPIface::doBigBreak()
+{
+    emit signalDoBigBreak();
+}
+
 #include "dcopiface.moc"
